///////////////////////////////////////////////////////////////////
// htmlplot（２次元グラフ描画用ツール）
//////////////////////////////////////////////////////////////////
var HTMLplot = function( parameters ){
	parameters = parameters || {}

	//HTMLのid属性
	this.dom = {};
	this.dom.canvasFrame = parameters.canvasFrameID;
	this.dom.inputText = parameters.inputTextID;
	this.dom.outputText = parameters.outputTextID;
	this.dom.inputDiv = parameters.inputDivID;
	this.dom.outputDiv = parameters.outputDivID;
	this.dom.downloadPNG =  parameters.downloadPictureID;
	this.dom.downloadCommand =  parameters.downloadCommandID;

	//計算範囲（x軸）
	this.x = {}
	this.x.min = ( parameters.xmin !== undefined )? parameters.xmin : -10; 
	this.x.max = ( parameters.xmax !== undefined )? parameters.xmax : 10; 
	//計算範囲（媒介変数）
	this.t = {}
	this.t.min = ( parameters.tmin !== undefined )? parameters.tmin : 0; 
	this.t.max = ( parameters.tmax !== undefined )? parameters.tmax : 10; 
	//データサンプル数
	this.samples =  ( parameters.samples !== undefined )? parameters.samples : 100;

	this.width = ( parameters.width !== undefined )? parameters.width :640;
	this.height = ( parameters.height !== undefined )? parameters.height :480;


	//Plot2Dクラスのオブジェクト
	this.plot2D = new Plot2D( this.dom.canvasFrame );

	//
	this.querys = [];
	this.commands = [];

	this.mode = null;
	this.downloadFileName = null;
	this.lastPlotQuery = null;

	this.parametricEnable = false;
	this.parametricEquation = null;



	this.plot2D.options.axesDefaults.pad = 1.0;
	this.plot2D.options.axes.xaxis.label = "x";
	this.plot2D.options.axes.yaxis.label = "y";
	this.plot2D.options.axes.xaxis.min = null;
	this.plot2D.options.axes.xaxis.max = null;
	this.plot2D.options.axes.xaxis.tickInterval = null;
	this.plot2D.options.axes.yaxis.min = null;
	this.plot2D.options.axes.yaxis.max = null;
	this.plot2D.options.axes.yaxis.tickInterval = null;


	//チェックボックスの値を取得する
	this.showLine = true;  //線描画の有無
	this.lineWidth = 2.5;

	this.marker = {
		show : false,
		size : 9
	};

	//this.plot2D.options.axes.yaxis.labelOptions = { angle: -90};

	this.plot2D.options.legend.show = true;        //凡例描画の有無
	this.plot2D.options.legend.location = "ne";//凡例の設置場所 'nw'：左上, 'n'：上, 'ne'：右上, 'e'：右, 'se'：右下, 's'：下, 'sw'：左下, 'w'：左
	this.plot2D.options.legend.placement = "insideGrid";//凡例の設置場所（デフォルト：'insideGrid'）（値 = 'insideGrid' | 'outsideGrid'）


	this.scale = { x:"liner", y:"liner" };
	this.setSize();
	this.start();

}

HTMLplot.prototype.setSize = function() {

	document.getElementById( this.dom.canvasFrame ).style.width  = this.width  + "px";
	document.getElementById( this.dom.canvasFrame ).style.height = this.height + "px";

}
HTMLplot.prototype.start = function() {


	//URLからqueryを取得する
	this.getURLQuery();

	if( !this.mode ){

		//イベントの準備
		this.initEvent();

	} else if( this.mode == "plot" || this.mode == "parametricPlot" ) {


		//最後の plot のみを描画する
		var plotNums = [];
		var replotNums = [];

		for(var i = 0; i < this.querys.length; i++ ){

			var text = this.querys[i];

			if( text.indexOf("replot") > -1 )    replotNums.push( i );
			else if( text.indexOf("plot") > -1 ) plotNums.push( i );

		}

		// plot コマンドが入力された最後のクエリ番号を格納
		var n = null;
		if( plotNums.length > 0 ) n = plotNums[ plotNums.length-1 ];

		this.lastPlotQuery = this.querys[ n ];

		for(var i = 0; i < this.querys.length; i++ ){

			//最後のplotコマンド以外はスルー
			if( plotNums.indexOf( i ) > -1 && i != n ) continue;

			//最後のplotコマンドより後のreplotコマンド以外はスルー
			if( replotNums.indexOf( i ) > -1 && ( replotNums[ replotNums.length - 1 ] != i || n > i ) ) continue;

			this.inputCommand( this.querys[i] );

		}

	}

}

HTMLplot.prototype.getURLQuery = function (){

	if( 1 < window.location.search.length ){

		// 最初の1文字 (?記号) を除いた文字列を取得する
		var query = window.location.search.substring( 1 );

		// クエリの区切り記号 (&) で文字列を配列に分割する
		var parameters = query.split( '&' );

		for( var i = 0; i < parameters.length; i++ ){

			// パラメータ名とパラメータ値に分割する
			var element = parameters[ i ].split( '=' );

			var paramName = decodeURIComponent( element[ 0 ] );
			var paramValue = decodeURIComponent( element[ 1 ] );

			if( paramName === "mode" ){

				this.mode = paramValue;

			} else {

				this.querys.push( paramValue );

			}

		}

	}
}
HTMLplot.prototype.setURLQuery = function ( ){

	if( this.commands.length >0 ){

		var query = "";
		for( var i = 0; i < this.commands.length; i++ ){

			query += "&q" + i + "=" + this.commands[i];
			
		}

		var mode = ( this.parametricEnable )? "parametricPlot" : "plot";

		var URL = window.location + "?mode=" + mode + query;

		var width = this.width + 50;
		var height = this.height + 50;

		window.open( URL ,"_blank", "menubar=no,width=" + width + ",height="+ height +"");

	}

}

////////////////////////////////////////////////////////////////////
// イベント準備関数
////////////////////////////////////////////////////////////////////
var textLines = "";

HTMLplot.prototype.initEvent = function () {
	var scope = this;
    document.getElementById( this.dom.inputDiv ).style.display = "block";

	document.getElementById( this.dom.inputText ).focus();
	document.getElementById( this.dom.inputText ).addEventListener( "keyup" , function ( e ) {

		if( e.keyCode === 13) {	// Enter ボタンが押された場合

			//入力されたテキストの取得
			var text =  document.getElementById( scope.dom.inputText ).value;

			scope.mode = "input";
			scope.inputCommand( text );

			scope.currentCommandNumber =  scope.commands.length;

		} else if( e.keyCode === 38 && scope.commands.length > 0){ // 上ボタンが押された場合

			scope.currentCommandNumber--;
			if(scope.currentCommandNumber < 0) scope.currentCommandNumber = 0;

			document.getElementById( scope.dom.inputText ).value = scope.commands[ scope.currentCommandNumber ];

		} else if( e.keyCode === 40  && scope.commands.length > 0){ // 下ボタンが押された場合

			scope.currentCommandNumber++;

			if(scope.currentCommandNumber <= scope.commands.length ) {

				scope.currentCommandNumber = scope.commands.length - 1;
				document.getElementById( scope.dom.inputText ).value = scope.commands[ scope.currentCommandNumber ];

			} else {

				document.getElementById( scope.dom.inputText ).value = "";

			}

		}
		
	});


	window.addEventListener("click", function () {
			document.getElementById( scope.dom.inputText ).focus();
		}, false );

	// デフォル処理をキャンセル
	var onCancel = function( e ){
		if( e.preventDefault ) e.preventDefault();
		return false;
	};
	window.addEventListener("dragover", onCancel, false);
	window.addEventListener("dragenter", onCancel, false);
	window.addEventListener("drop", function ( e ) {

		if( e.preventDefault ) e.preventDefault();

		var file = e.dataTransfer.files[0]; // File オブジェクトを取得

		var reader = new FileReader();      // ファイルリーダー生成
		reader.readAsText(file, "utf-8");// テキストとしてファイルを読み込む
		reader.onload = function( e ) {
			var text = e.target.result;

			scope.mode = "input";
			scope.querys = text.split( "\n" );		

			for(var i = 0; i < scope.querys.length; i++ ){

				scope.inputCommand( scope.querys[i] );

			}

		};

	}, false );

}

////////////////////////////////////////////////////////////////////
// コマンド入力関数
////////////////////////////////////////////////////////////////////

HTMLplot.prototype.inputCommand = function ( text ){
	var scope = this;
	if( text == "" || text == null ) return;
	this.commands.push( text );

	//テキスト先頭と末尾のスペースの排除、連続するスペースを削除、
	text = text.replace( /(^\s+)|(\s+$)/g, "").replace( /\s+/g , " ");

	//「"」は「'」へ置き換える
	text = text.replace(/"/g, "'");

	//「,」の前後はスペースを追加
	text = text.replace(/,/g, " , ")

	//「#の後はコメントアウト」
	text = text.replace( /#.*/g, "");

	text = text.replace( /xl\s+/g, "xlabel ");
	text = text.replace( /yl\s+/g, "ylabel ");
	text = text.replace( /xr\s*\[/g, "xrange[");
	text = text.replace( /yr\s*\[/g, "yrange[");
	text = text.replace( /tr\s*\[/g, "trange[");
	text = text.replace( /ur\s*\[/g, "urange[");

	text = text.replace( /\sw\s+/g, " with ");
	text = text.replace( /\slw\s+/g, " linewidth ");
	text = text.replace( /\sps\s+/g, " pointsize ");

	text = text.replace( /\su\s+/g, " using ");
	text = text.replace( /\sl\s+|\s+l$/g, " lines ");
	text = text.replace( /\sd\s+|\s+d$/g, " dots ");
	text = text.replace( /\sp\s+|\s+p$/g, " points "); 
	text = text.replace( /\slp\s+|\s+lp$/g, " linespoints "); 

	//記号の前後のスペースを削除
	text = text.replace(
		/(\s*[,:;^+*-/)(\[\]]\s*)/g, 
		function (str, p1, offset, s) { return p1.replace( /(^\s+)|(\s+$)/g, "") }
	);

	//setコマンドの実行
	if ( text.indexOf("unset") > -1 ){

		//スケールの変更
		text.replace( 
			/logscale\s([xy])/i, 
			function ( str, p1, offset, s) {
				scope.scale[ p1 ] = "liner";
			}
		);

		//凡例の非表示
		text.replace( 
			/key/i, 
			function ( str, p1, offset, s) {
				scope.plot2D.options.legend.show = false;
			}
		);

		//ラベルの非表示
		text.replace( 
			/([xy]*)label/i, 
			function ( str, p1, offset, s) {
				if( p1 == "x" || p1 == "") scope.plot2D.options.axes.xaxis.label = "";
				if( p1 == "y" || p1 == "") scope.plot2D.options.axes.yaxis.label = "";
			}
		);



	} else if( text.indexOf("set") > -1){

		//描画範囲の変更
		this.checkRange( text );

		//ラベルの変更
		this.checkLabel( text );		

		//凡例の変更
		this.checkLegend( text );

		//軸スケールの変更
		text.replace( 
			/logscale\s([xy])/i, 
			function ( str, p1, offset, s) {
				scope.scale[ p1 ] = "log";
			}
		);

		//軸スケールの変更
		text.replace( 
			/samples\s([0-9]+)/, 
			function ( str, p1, offset, s) {
				scope.samples = parseInt( p1 );
			}
		);
		
		//サイズの変更
		text.replace( 
			/size\s([0-9]+)\s([0-9]+)/i, 
			function ( str, p1, p2, offset, s) {
				scope.width = parseInt( p1 );
				scope.height = parseInt( p2 );
				scope.setSize();
			}
		);
	
		if( text.indexOf("parametric") >-1 ) this.parametricEnable = true;


	} else if ( text.indexOf("replot") > -1 ){ //replot コマンドの実行


		if( this.mode == "plot" || this.mode == "parametricPlot" ){

			//描画データの計算
			//this.calculate( this.lastPlotQuery , this.mode );
			//this.plot();

			this.inputCommand( this.lastPlotQuery );


		} else if ( this.mode == "input" ){

			this.setURLQuery();

		}

	} else if( text.indexOf("plot") > -1 ){	//plotコマンドの実行

		if( this.mode == "plot" || this.mode == "parametricPlot" ){

			//描画データの計算
			var flag = this.calculate( text, this.mode );
			if( flag ) this.plot();

		} else if ( this.mode == "input" ){

			this.setURLQuery();

		}

	} else if( text.indexOf("load") > -1 ){	// load コマンドの実行

		if( this.mode == "plot" || this.mode == "parametricPlot"){

			var filename = "";
			//スケールの変更
			text.replace( 
				/load\s'(.+)'/i, 
				function ( str, p1, offset, s) {
					filename = p1;
				}
			);

			if( filename ){

				var xmlHttp = new XMLHttpRequest();
				xmlHttp.open("GET", filename , false);
				xmlHttp.send( null );

				var str = xmlHttp.responseText;
				this.querys	= str.split( "\n" );		

				for(var i = 0; i < this.querys.length; i++ ){

					this.inputCommand( this.querys[i] );

				}


			}

		} else if ( this.mode == "input" ){

			this.setURLQuery();

		}

	}


	var texts = "";
	for(var i = this.commands.length-1 ; i >=0 ; i-- ){
		//入力されたテキストの一覧を取得
		texts += "htmlplot &gt; " + this.commands[i]+ "<br>";
	}

	if( this.mode == "input" ){
		document.getElementById( this.dom.outputText ).innerHTML = texts;
		document.getElementById( this.dom.inputText ).value = "";
	}
	
};

////////////////////////////////////////////////////////////////////
//描画メソッド
////////////////////////////////////////////////////////////////////
HTMLplot.prototype.plot = function( ){

    document.getElementById( this.dom.outputDiv ).style.display = "block";

	//メソッドによる描画
	if( this.scale.x == "liner" && this.scale.y == "liner" ){

		this.plot2D.linerPlot();

	} else if( this.scale.x == "liner" && this.scale.y == "log" ){

		this.plot2D.logPlot();

	} else if( this.scale.x == "log" && this.scale.y == "liner" ){

		this.plot2D.loglinerPlot();

	} else if( this.scale.x == "log" && this.scale.y == "log" ){

		this.plot2D.loglogPlot();

	}

	this.makePicture();

}

////////////////////////////////////////////////////////////////////
//描画範囲の指定
////////////////////////////////////////////////////////////////////
HTMLplot.prototype.checkRange = function ( str, mode ){
	var scope = this;

	str.replace( 
		/\[(.*):(.*)\]/, 
		function ( _str, p1, p2, offset, s) {

			if( str.indexOf( "xrange" ) > -1 || mode == "plot" ){


				//scope.plot2D.options.axes.xaxis.min = parseFloat( p1 );
				//scope.plot2D.options.axes.xaxis.max = parseFloat( p2 );
				//var d = scope.plot2D.options.axes.xaxis.max - scope.plot2D.options.axes.xaxis.min;
				//var keta = (Math.log( d )/ Math.LN10 ).toFixed(0);
				//scope.plot2D.options.axes.xaxis.tickInterval = Math.pow( 10, keta -1 );

				scope.x.min = parseFloat( p1 );
				scope.x.max = parseFloat( p2 );

			} else if( str.indexOf( "yrange" ) > -1 ) {

				scope.plot2D.options.axes.yaxis.min = parseFloat( p1 );
				scope.plot2D.options.axes.yaxis.max = parseFloat( p2 );
				var d = scope.plot2D.options.axes.yaxis.max - scope.plot2D.options.axes.yaxis.min;
				var keta = (Math.log( d )/ Math.LN10 ).toFixed(0);
				scope.plot2D.options.axes.yaxis.tickInterval = Math.pow( 10, keta -1 );

			} else if( str.indexOf( "trange" ) > -1 || mode == "parametricPlot" ) {

				scope.t.min = parseFloat( p1 );
				scope.t.max = parseFloat( p2 );

			}

			str = str.replace (_str, " ");
		}
	);

	return str;
}

HTMLplot.prototype.checkLabel = function( str ){
	var scope = this;

	//ラベルの変更
	str.replace( 
		/xlabel\s*'(.*)'/i, 
		function ( str, p1, offset, s) {
			scope.plot2D.options.axes.xaxis.label = p1;
		}
	);
	str.replace( 
		/ylabel\s*'(.*)'\s*(rotation)*/i, 
		function ( str, p1, p2, offset, s) {
			scope.plot2D.options.axes.yaxis.label = p1;
			if(p2) scope.plot2D.options.axes.yaxis.labelOptions = { angle: -90};
		}
	);



}


HTMLplot.prototype.checkLegend = function( str ){
	var scope = this;

	//凡例の表示の有無
	str.replace( 
		/key\s(top|bottom|right|left)(\s|(top|bottom|right|left))*/g, 
		function ( str, p1, p2, offset, s) {

			scope.plot2D.options.legend.show = true;

			if( p1 == "top" || p2 == "top"){

				var a = ( p1 == "top" )? p2 : p1;

				if( a == "left")       scope.plot2D.options.legend.location = 'nw';
				else if( a == "right") scope.plot2D.options.legend.location = 'ne';
				else                   scope.plot2D.options.legend.location = 'n';

			} else if( p1 == "bottom" || p2 == "bottom"){
				var a = ( p1 == "bottom" )? p2 : p1;

				if( a == "left")       scope.plot2D.options.legend.location = 'sw';
				else if( a == "right") scope.plot2D.options.legend.location = 'se';
				else                   scope.plot2D.options.legend.location = 's';

			} else if( p1 == "left" ){

				scope.plot2D.options.legend.location = 'w';

			} else if( p1 == "right" ){
			
				scope.plot2D.options.legend.location = 'e';

			}

		}
	);

	//凡例の表示の有無
	str.replace( 
		/key\s(outside|below)/g, 
		function ( str, p1, offset, s) {

			if( p1 == "outside"){
				scope.plot2D.options.legend.placement = "outsideGrid";
				scope.plot2D.options.legend.location = "ne";

			} else if( p1 == "below"){
				scope.plot2D.options.legend.placement = "outsideGrid";
				scope.plot2D.options.legend.location = "se";
			}
		}
	);
}

////////////////////////////////////////////////////////////////////
//描画データ計算関数
////////////////////////////////////////////////////////////////////
HTMLplot.prototype.calculate = function( text , mode ) {
	mode = mode || "plot"
	var scope = this;

	this.downloadFileName = text;

	// [xmin:xmax]が指定されている場合
	text = this.checkRange( text , mode );

	text = text.replace( "plot ", "");

	//描画データのクリアー
	this.plot2D.clearData();

	//データ列オプション配列
	var series = []; 

	try {

		if( mode == "plot" ){

			//テキストエリアに入力された関数を取得する
			var fs = text.split(","); //改行で分割する

			//描画データの準備
			for (var n = 0; n < fs.length; n++) {
				var f = fs[n];

				//「with」キーワードの取得
				f = this.getWith( f );

				//外部ファイルによる描画データを利用する場合のファイル名
				var filename = "";
				f.replace( 
					/'([a-z0-9._]+)'/i, 
					function ( _str, p1, offset, s) { 
						filename =  p1;
					}
				);
				var data = [];  //描画点データ配列の初期化
				var uu = "";

				if( filename ){

					var u1 = 1;
					var u2 = 2;

					f = f.replace( 
						/using\s([0-9]):([0-9])/, 
						function ( _str, p1, p2, offset, s) { 
							u1 = parseInt( p1 );
							u2 = parseInt( p2 );
							uu = "[" + u1 + ":" + u2 + "]"
							//該当部分を消去
							return _str.replace (_str, "");
						}
					);

					var xmlHttp = new XMLHttpRequest();
					xmlHttp.open("GET", filename , false);
					xmlHttp.send( null );

					var str = xmlHttp.responseText;
					var lines = str.split( "\n" );		


					for( var i = 0; i < lines.length; i++ ){
						var line = lines[i];
						line = line.replace( /\t/g, " ");
						var as =  line.split( " " );
						var x = parseFloat( as[ u1 - 1 ] );
						var y = parseFloat( as[ u2 - 1 ] );
						if( !isFinite( y ) ) continue;

						data.push([x, y]);  //描画点データの格納
					}

				} else {

					//式の検証
					f = this.replaceEquation(f);

					for (var i = 0; i <= this.samples; i++) {
						var x = this.x.min + (this.x.max - this.x.min) * i / this.samples;  //xの値
						var y = eval( f );  //yの値

						if( !isFinite(y) ) continue;
						data.push([x, y]);  //描画点データの格納
					}

				}

				//データ列オプション配列に追加
				series.push({
					showLine: this.now.showLine,     //線描画の有無
					lineWidth: this.now.lineWidth,   //線幅
					label: "y=" + f + uu,        //凡例の設定
					markerOptions: { 
						show: this.now.markerShow,
						size: this.now.markerSize
					} 
				});


				//「pushData」メソッドによるデータの追加
				this.plot2D.pushData( data );
			}

		} else if( mode == "parametricPlot" ){

			//「with」キーワードの取得
			 text  = this.getWith( text );


			var regexp = /(.*t.*),(.*t.*)/g;
			var results = regexp.exec( text );

			this.parametricEquation = {x:results[1], y:results[2]};

			//テキストエリアに入力された関数を取得する
			var fx = this.parametricEquation.x; //テキストを取得
			var fy = this.parametricEquation.y; //テキストを取得

			fx = this.replaceEquation(fx);
			fy = this.replaceEquation(fy);

			//データ列オプション配列に追加
			series.push({
				showLine: this.now.showLine,     //線描画の有無
				lineWidth: this.now.lineWidth,   //線幅
				label: "f=(" + fx + ", " + fy + ")",             //凡例の設定
				markerOptions: { 
					show: this.now.markerShow,
					size: this.now.markerSize
				} 
			});

			this.downloadFileName = "f=(" + fx + ", " + fy + ")";

			var data = [];                       //描画点データ配列の初期化
			for (var i = 0; i <= this.samples; i++) {
				var t = this.t.min + (this.t.max - this.t.min) * i / this.samples;  //xの値
				var x = eval( fx );  //xの値
				var y = eval( fy );  //yの値
				if( !isFinite(x) || !isFinite(y) ) continue;

				data.push([x, y]);  //描画点データの格納

			}
			//「pushData」メソッドによるデータの追加
			this.plot2D.pushData( data );

		}

	} catch( e ) {

		document.getElementById( this.dom.canvasFrame ).innerHTML = e;
		return false;

	}

	this.plot2D.options.series = series;   //データ列オプション（線, 点, 凡例）
	return true;

}



HTMLplot.prototype.makePicture = function (){

	var img = this.plot2D.makeImage();	

	if( this.dom.downloadPNG ) {
		//canvas要素→DataURL形式
		document.getElementById( this.dom.downloadPNG ).href = img.src;

		//PNGファイル名の命名
		document.getElementById( this.dom.downloadPNG ).download = this.downloadFileName + ".png";

	}

	var outputs = [];
	for(var i = 0; i < this.querys.length; i++ ){

		outputs.push( this.querys[i] + "\n" );

	}

	//コマンドの保存
	var blob = new Blob( outputs , { "type" : "text/plain" });
	window.URL = window.URL || window.webkitURL;

	document.getElementById( this.dom.downloadCommand ).href = window.URL.createObjectURL( blob );
	document.getElementById( this.dom.downloadCommand ).download = this.downloadFileName + ".plt";

}

HTMLplot.prototype.replaceEquation = function ( eq ){
	eq = eq.replace(
		/([-+]?)(.*)(\^|\*\*)([0123456789.x]|log\(.*\)|sin\(.*\)|cos\(.*\)|tan\(.*\)|\(.*\))/g, 
		function (str, p1, p2, p3, p4, offset, s) { 
			return p1 + "pow(" + p2 + "," + p4 + ")";
		}
	);
	return eq;
}

HTMLplot.prototype.getWith = function ( text ){
	var scope = this;

	this.now = {};
	this.now.showLine = this.showLine;      //線描画の有無
	this.now.lineWidth = this.lineWidth;    //線幅
	this.now.markerShow = this.marker.show; //点描画の有無
	this.now.markerSize = this.marker.size;

	// withが指定されている場合
	text = text.replace( 
		/with\s([a-z]+)(\slinewidth\s[0-9]+)?(\spointsize\s[0-9]+)?/, 
		function ( _str, p1, p2, p3, offset, s) { 

			if( p1 == "dots" ){

				scope.now.showLine = false;  //線描画の有無
				scope.now.markerShow = true; //点描画の有無
				scope.now.markerSize = 2;

			} else if( p1 == "points" ){

				scope.now.showLine = false;  //線描画の有無
				scope.now.markerShow = true; //点描画の有無
				scope.now.markerSize = 5;

				if( p3 ){
					p3.replace( 
						/pointsize\s([0-9]+)/, 
						function ( _str, p1, offset, s) {
							scope.now.markerSize = parseFloat( p1 );
			
						}
					);
				}

			} else if( p1 == "lines" ){

				scope.now.showLine = true;  //線描画の有無
				scope.now.markerShow = false; //点描画の有無

				if( p2 ){
					p2.replace( 
						/linewidth\s([0-9]+)/, 
						function ( _str, p1, offset, s) {
							scope.now.lineWidth = parseFloat( p1 );
			
						}
					);
				}

			} else if( p1 == "linespoints" ){

				scope.now.showLine = true;  //線描画の有無
				scope.now.markerShow = true; //点描画の有無

				if( p2 ){
					p2.replace( 
						/linewidth\s([0-9]+)/, 
						function ( _str, p1, offset, s) {
							scope.now.lineWidth = parseFloat( p1 );
			
						}
					);
				}
				if( p3 ){
					p3.replace( 
						/pointsize\s([0-9]+)/, 
						function ( _str, p1, offset, s) {
							scope.now.markerSize = parseFloat( p1 );
			
						}
					);
				}
			}
			//該当部分を消去
			return _str.replace (_str, "");
		}
	);
	return text;
}



HTMLplot.prototype.defaultOptions = {
		//デフォルト軸オプション
		axesDefaults: {
			pad: 1.02,                        //軸の描画範囲のパッディング
			labelRenderer: $.jqplot.CanvasAxisLabelRenderer, //ラベルレンダラーの指定
			labelOptions: {
				show: true,                     //ラベル描画の有無（デフォルト：true）
				angle: -90,                     //ラベル描画角度（デフォルト：-90）
				fontFamily: 'Times New Roman',  //ラベルフォント（デフォルト：'"Trebuchet MS", Arial, Helvetica, sans-serif'）
				fontSize: '20px',               //ラベルフォントサイズ（デフォルト：'11pt'）
				fontWeight: 'bold',             //ラベルウェイト（デフォルト：'nomal'）
				textColor: '#666666'            //ラベルカラー（デフォルト：'#666666'）
			},
			tickRenderer: $.jqplot.CanvasAxisTickRenderer,
			tickOptions: {
				show: true,           //目盛マークと目盛ラベル描画の有無
				showLabel: true,      //目盛ラベル描画の有無
				showMark: true,       //目盛マーク描画の有無
				showGridline: true,   //グリッドラインの描画
				mark: 'outside',      //目盛マークの描画位置の指定（'outside', 'inside' or 'cross'）
				markSize: 4,          //目盛マークのサイズ（デフォルト：4）
				formatString: '',     //フォーマット指定子の設定（例「%.2f」）
				fontSize: '10pt',     //目盛ラベルフォントサイズ
				fontWeight: 'bold',   //目盛ラベルウェイト
				textColor: '#666666', //目盛ラベルカラー
				fontFamily: 'Times New Roman',  //目盛ラベルフォント
				angle: 0,             //目盛ラベル描画角度
				prefix: ''            //目盛ラベルのプレフィックス
			}
		},
		//軸オプション
		axes: {                        //軸のオプション
			xaxis: {                     //x軸のオプション
				label: 'x',                //x軸のラベル
				min: null,                    //x軸の最小値
				max: null,                    //x軸の最大値
				tickInterval: null,        //x軸の目盛間隔
				labelOptions: { angle: 0} //ラベルレンダラオプション
			},
			yaxis: {                     //y軸のオプション
				label: 'y', //y軸のラベル
				min: null,                    //y軸の最小値
				max: null,                  //y軸の最大値
				tickInterval: null,        //y軸の目盛間隔
				renderer: $.jqplot.LinerAxisRenderer,
				labelOptions: { angle: 0} //ラベルレンダラオプション
			},
			y2axis: {                     //y軸のオプション
				label: 'y2', //y軸のラベル
				min: null,                    //y軸の最小値
				max: null,                  //y軸の最大値
				tickInterval: null,        //y軸の目盛間隔
				renderer: $.jqplot.LinerAxisRenderer,
				labelOptions: { angle: 0} //ラベルレンダラオプション
			}
		},
		//グリッドオプション
		grid: {                  //グリッドオプション
			background: '#FFFFFF'  //背景色
		},
		//凡例オプション
		legend: {
			show: true,              //凡例の有無
			location: 'ne',          //凡例の設置場所 'nw'：左上, 'n'：上, 'ne'：右上, 'e'：右, 'se'：右下, 's'：下, 'sw'：左下, 'w'：左
			placement: 'insideGrid'  //凡例の設置場所（デフォルト：'insideGrid'）（値 = 'insideGrid' || 'outsideGrid'）
		},
		//カーソルオプション
		cursor: {
			show: true,                //カーソルの描画
			style: 'crosshair',        //カーソルの種類（デフォルト：'crosshair'）
			zoom: true,                  //ズームの可否（デフォルト：'false'）
			looseZoom: true,             //あいまい値利用の有無（デフォルト：'true'）
			clickReset: true,            //クリックによるズームのリセット有無（デフォルト：'false'）
			dblClickReset: false,        //あいまい値利用の有無（デフォルト：'true'）
			constrainOutsideZoom: false,  //グラフ描画の外側もズーム対象としない（デフォルト：true）
			showTooltipOutsideZoom: true //「constrainOutsideZoom: false」の場合に、ツールチップに外側の値を描画
		},
		//ハイライトオプション
		highlighter: {
			show: true,               //ハイライト描画の有無（デフォルト：true）
			showTooltip: true,        //ツールチップ描画の有無（デフォルト：true）
			tooltipLocation: 'ne',    //ツールチップ描画の方向（デフォルト：'ne'）
			fadeTooltip: true,        //ツールチップフェード描画の有無（デフォルト：true）
			tooltipFadeSpeed: 'def',  //ツールチップフェードの速度（デフォルト：'fast'）（'slow','def','fast', ミリ秒）
			tooltipAxes: 'xy',        //ツールチップに描画うする軸（デフォルト：'xy'）（'x', 'y' , 'xy', 'yx'）
			sizeAdjust: 7.5           //マーカーのサイズ（デフォルト：7.5）
		},
		seriesDefaults :{
			show: true,     // wether to render the series.
			xaxis: 'xaxis', // either 'xaxis' or 'x2axis'.
			yaxis: 'yaxis', // either 'yaxis' or 'y2axis'.
			label: '',      // label to use in the legend for this line.
			color: '',      // CSS color spec to use for the line.  Determined automatically.
			lineWidth: 2.5, // Width of the line in pixels.
			shadow: true,   // show shadow or not.
			shadowAngle: 45,    // angle (degrees) of the shadow, clockwise from x axis.
			shadowOffset: 1.25, // offset from the line of the shadow.
			shadowDepth: 3,     // Number of strokes to make when drawing shadow.  Each
			            // stroke offset by shadowOffset from the last.
			shadowAlpha: 0.1,   // Opacity of the shadow.
			showLine: true,     // whether to render the line segments or not.
			showMarker: true,   // render the data point markers or not.
			fill: false,        // fill under the line,
			fillAndStroke: false,       // *stroke a line at top of fill area.
			fillColor: undefined,       // *custom fill color for filled lines (default is line color).
			fillAlpha: undefined,       // *custom alpha to apply to fillColor.
			renderer: $.jqplot.LineRenderer,    // renderer used to draw the series.
			rendererOptions: {}, // options passed to the renderer.  LineRenderer has no options.
			markerRenderer: $.jqplot.MarkerRenderer,    // renderer to use to draw the data
			                                    // point markers.
			markerOptions: {
				show: true,             // wether to show data point markers.
				style: 'filledCircle',  // circle, diamond, square, filledCircle.
				                    // filledDiamond or filledSquare.
				lineWidth: 2,       // width of the stroke drawing the marker.
				size: 9,            // size (diameter, edge length, etc.) of the marker.
				color: undefined,    // color of marker, set to color of line by default.
				shadow: true,       // wether to draw shadow on marker or not.
				shadowAngle: 45,    // angle of the shadow.  Clockwise from x axis.
				shadowOffset: 1,    // offset from the line of the shadow,
				shadowDepth: 3,     // Number of strokes to make when drawing shadow.  Each stroke
				                // offset by shadowOffset from the last.
				shadowAlpha: 0.07   // Opacity of the shadow
			}

		}
	};